![PyPI - License](https://img.shields.io/pypi/l/sytd)
![PyPI](https://img.shields.io/pypi/v/sytd)
![PyPI - Status](https://img.shields.io/pypi/status/sytd)

# Simple YouTube Downloader
![](https://raw.githubusercontent.com/tomg404/Simple-YouTube-Downloader/master/images/screenshot_1.png)

## Installation
```
pip install sytd
```

## Usage
```
python -m sytd

simple-youtube-downloader

sytd
```
